@@ -9,14 +9,14 @@
  *                         \/  \/     |_|    |_|                           *
  *                                                                         *
  *                           Wiimms ISO Tools                              *
- *                         http://wit.wiimm.de/                            *
+ *                         https://wit.wiimm.de/                           *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
  *   This file is part of the WIT project.                                 *
- *   Visit http://wit.wiimm.de/ for project details and sources.           *
+ *   Visit https://wit.wiimm.de/ for project details and sources.          *
  *                                                                         *
- *   Copyright (c) 2009-2015 by Dirk Clemens <wiimm@wiimm.de>              *
+ *   Copyright (c) 2009-2017 by Dirk Clemens <wiimm@wiimm.de>              *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
@@ -187,10 +187,23 @@ enum // some constants
 
 #define WII_MAX_DISC_SIZE ((u64)WII_MAX_SECTORS*(u64)WII_SECTOR_SIZE)
 
+//
+///////////////////////////////////////////////////////////////////////////////
+///////////////			misc				///////////////
+///////////////////////////////////////////////////////////////////////////////
+// [[id6_t]]
+
+typedef char id6_t[7];
+
+//-------------------------------------------------------------------------
+
+extern const char skeleton_marker[10];
+
 //
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			enum wd_disc_type_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_disc_type_t]]
 
 typedef enum wd_disc_type_t
 {
@@ -210,6 +223,7 @@ typedef enum wd_disc_type_t
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			enum wd_disc_attrib_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_disc_attrib_t]]
 
 typedef enum wd_disc_attrib_t
 {
@@ -235,6 +249,7 @@ typedef enum wd_disc_attrib_t
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			enum wd_compression_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_compression_t]]
 
 typedef enum wd_compression_t
 {
@@ -286,6 +301,7 @@ ccp wd_print_compression
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct dol_header_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[dol_header_t]]
 
 typedef struct dol_header_t
 {
@@ -303,6 +319,7 @@ void ntoh_dol_header ( dol_header_t * dest, const dol_header_t * src );
 void hton_dol_header ( dol_header_t * dest, const dol_header_t * src );
 
 //-----------------------------------------------------------------------------
+// [[dol_record_t]]
 
 typedef struct dol_record_t
 {
@@ -334,6 +351,7 @@ const dol_record_t * search_dol_record
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////		    struct wbfs_inode_info_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wbfs_inode_info_t]]
 
 typedef struct wbfs_inode_info_t
 {
@@ -399,6 +417,7 @@ void hton_inode_info ( wbfs_inode_info_t * dest, const wbfs_inode_info_t * src )
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_header_128_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_header_128_t]]
 
 typedef struct wd_header_128_t
 {
@@ -450,6 +469,7 @@ wd_disc_type_t get_header_128_disc_type
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_header_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_header_t]]
 
 typedef struct wd_header_t
 {
@@ -503,6 +523,7 @@ wd_disc_type_t get_header_disc_type
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_boot_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_boot_t]]
 
 typedef struct wd_boot_t
 {
@@ -523,6 +544,7 @@ void hton_boot ( wd_boot_t * dest, const wd_boot_t * src );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			enum wd_age_rating_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_age_rating_t]]
 
 typedef enum wd_age_rating_t
 {
@@ -555,6 +577,7 @@ ccp wd_print_age_rating
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_region_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_region_t]]
 
 typedef struct wd_region_t
 {
@@ -569,6 +592,7 @@ __attribute__ ((packed)) wd_region_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////		    struct wd_ptab_info_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_ptab_info_t]]
 
 typedef struct wd_ptab_info_t
 {
@@ -581,6 +605,7 @@ __attribute__ ((packed)) wd_ptab_info_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////		    struct wd_ptab_entry_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_ptab_entry_t]]
 
 typedef struct wd_ptab_entry_t
 {
@@ -593,6 +618,7 @@ __attribute__ ((packed)) wd_ptab_entry_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_ptab_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_ptab_t]]
 
 typedef struct wd_ptab_t // example for a good partition table
 {
@@ -605,6 +631,7 @@ __attribute__ ((packed)) wd_ptab_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_ticket_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_ticket_t]]
 
 typedef struct wd_ticket_t
 {
@@ -653,6 +680,7 @@ bool ticket_is_fake_signed ( const wd_ticket_t * ticket, u32 ticket_size );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_part_header_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_part_header_t]]
 
 typedef struct wd_part_header_t
 {
@@ -674,6 +702,7 @@ void hton_part_header ( wd_part_header_t * dest, const wd_part_header_t * src );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////		      struct wd_tmd_content_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_tmd_content_t]]
 
 typedef struct wd_tmd_content_t
 {
@@ -689,6 +718,7 @@ __attribute__ ((packed)) wd_tmd_content_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			    struct wd_tmd_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_tmd_t]]
 
 typedef struct wd_tmd_t
 {
@@ -732,6 +762,7 @@ bool tmd_is_fake_signed ( const wd_tmd_t * tmd, u32 tmd_size );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////		    struct wd_part_control_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_part_control_t]]
 
 typedef struct wd_part_control_t
 {
@@ -761,7 +792,7 @@ wd_part_control_t; // packing not needed
 
 //----- setup
 
-// 0:ok, 1:error, sizes to large
+// 0:ok, 1:error, sizes too large
 int clear_part_control
 	( wd_part_control_t * pc, u32 tmd_size, u32 cert_size, u64 data_size );
 
@@ -777,6 +808,7 @@ int part_control_is_fake_signed ( const wd_part_control_t * pc );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_part_sector_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_part_sector_t]]
 
 typedef struct wd_part_sector_t
 {
@@ -795,6 +827,7 @@ __attribute__ ((packed)) wd_part_sector_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wd_fst_item_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wd_fst_item_t]]
 
 typedef struct wd_fst_item_t
 {
@@ -813,6 +846,7 @@ __attribute__ ((packed)) wd_fst_item_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wbfs_head_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wbfs_head_t]]
 
 typedef struct wbfs_head_t
 {
@@ -836,6 +870,7 @@ __attribute__ ((packed)) wbfs_head_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wbfs_disc_info_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wbfs_disc_info_t]]
 
 typedef struct wbfs_disc_info_t
 {
@@ -886,6 +921,7 @@ extern const char wpat_magic[12];
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			enum wpat_type_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_type_t]]
 
 typedef enum wpat_type_t
 {
@@ -932,6 +968,7 @@ ccp wpat_get_type_name ( wpat_type_t type, ccp return_if_invalid );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			union wpat_size_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_size_t]]
 
 typedef union wpat_size_t
 {
@@ -950,6 +987,7 @@ wpat_size_t wpat_calc_size ( wpat_type_t type, u32 size );
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_header_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_header_t]]
 
 typedef struct wpat_header_t
 {
@@ -967,6 +1005,7 @@ __attribute__ ((packed)) wpat_header_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_comment_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_comment_t]]
 
 typedef struct wpat_comment_t
 {
@@ -979,6 +1018,7 @@ __attribute__ ((packed)) wpat_comment_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_data_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_data_t]]
 
 typedef struct wpat_data_t
 {
@@ -999,6 +1039,7 @@ __attribute__ ((packed)) wpat_data_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_filename_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_filename_t]]
 
 typedef struct wpat_filename_t
 {
@@ -1011,6 +1052,7 @@ __attribute__ ((packed)) wpat_filename_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_filenames_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_filenames_t]]
 
 typedef struct wpat_filenames_t
 {
@@ -1025,6 +1067,7 @@ __attribute__ ((packed)) wpat_filenames_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_patch_file_t	///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_patch_file_t]]
 
 typedef struct wpat_patch_file_t
 {
@@ -1041,6 +1084,7 @@ __attribute__ ((packed)) wpat_patch_file_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_toc_header_t	///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_toc_header_t]]
 
 typedef struct wpat_toc_header_t
 {
@@ -1056,6 +1100,7 @@ __attribute__ ((packed)) wpat_toc_header_t;
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			struct wpat_toc_file_t		///////////////
 ///////////////////////////////////////////////////////////////////////////////
+// [[wpat_toc_file_t]]
 
 typedef struct wpat_toc_file_t
 {
@@ -1066,13 +1111,6 @@ typedef struct wpat_toc_file_t
 }
 __attribute__ ((packed)) wpat_toc_file_t;
 
-//
-///////////////////////////////////////////////////////////////////////////////
-///////////////			consts & vars			///////////////
-///////////////////////////////////////////////////////////////////////////////
-
-extern const char skeleton_marker[10];
-
 //
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////			    E N D			///////////////
