@@ -9,14 +9,14 @@
  *                         \/  \/     |_|    |_|                           *
  *                                                                         *
  *                           Wiimms ISO Tools                              *
- *                         http://wit.wiimm.de/                            *
+ *                         https://wit.wiimm.de/                           *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
  *   This file is part of the WIT project.                                 *
- *   Visit http://wit.wiimm.de/ for project details and sources.           *
+ *   Visit https://wit.wiimm.de/ for project details and sources.          *
  *                                                                         *
- *   Copyright (c) 2009-2015 by Dirk Clemens <wiimm@wiimm.de>              *
+ *   Copyright (c) 2009-2017 by Dirk Clemens <wiimm@wiimm.de>              *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
@@ -39,7 +39,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "debug.h"
+#include "dclib/dclib-debug.h"
 #include "lib-std.h"
 #include "match-pattern.h"
 
@@ -103,9 +103,9 @@ static const struct macro_tab_t macro_tab[] =
     { 5, "nosys",	"-/sys/" },
     { 5, "files",	"+/files/" },
     { 7, "nofiles",	"-/files/" },
-    { 3, "wit",		"2+/h3.bin;1+/sys/fst.bin;+" },
-    { 3, "wwt",		"2+/h3.bin;1+/sys/fst.bin;+" },
-    { 7, "compose",	"+/cert.bin;3+/disc/;2+/*$;1+/sys/fst.bin;+" },
+    { 3, "wit",		"3+/h3.bin;1+/sys/fst.bin;1+/sys/fst+.bin;+" },
+    { 3, "wwt",		"3+/h3.bin;2+/sys/fst.bin;1+/sys/fst+.bin;+" },
+    { 7, "compose",	"+/cert.bin;4+/disc/;3+/*$;2+/sys/fst.bin;1+/sys/fst+.bin;+" },
     { 4, "neek",	"3+/setup.txt;2+/h3.bin;1+/disc/;+" },
     { 5, "sneek",	"3+/setup.txt;2+/h3.bin;1+/disc/;+" },
 
@@ -365,317 +365,6 @@ int MatchFilePatternFST
 	&& !MatchFilePattern(it->param,it->fst_name,'/');
 }
 
-//
-///////////////////////////////////////////////////////////////////////////////
-///////////////                 MatchPattern()                  ///////////////
-///////////////////////////////////////////////////////////////////////////////
-
-static ccp AnalyseBrackets
-(
-    ccp		pattern,
-    ccp		* p_start,
-    bool	* p_negate,
-    int		* p_multiple
-)
-{
-    ASSERT(pattern);
-
-    bool negate = false;
-    if ( *pattern == '^' )
-    {
-	pattern++;
-	negate = true;
-    }
-    if (p_negate)
-	*p_negate = negate;
-
-    int multiple = 0;
-    if ( *pattern == '+' )
-    {
-	pattern++;
-	multiple = 1;
-    }
-    else if ( *pattern == '*' )
-    {
-	pattern++;
-	multiple = 2;
-    }
-    if (p_multiple)
-	*p_multiple = multiple;
-
-    if (p_start)
-	*p_start = pattern;
-
-    if (*pattern) // ']' allowed in first position
-	pattern++;
-    while ( *pattern && *pattern++ != ']' ) // find end
-	;
-
-    return pattern;
-}
-
-//-----------------------------------------------------------------------------
-
-static bool MatchBracktes
-(
-    char	ch,
-    ccp		pattern,
-    bool	negate
-)
-{
-    if (!ch)
-	return false;
-
-    bool ok = false;
-    ccp p = pattern;
-    for (; !ok && *p && ( p == pattern || *p != ']' ); p++ )
-    {
-	if ( *p == '-' )
-	{
-	    if ( ch <= *++p && ch >= p[-2] )
-	    {
-		if (negate)
-		    return false;
-		ok = true;
-	    }
-	}
-	else
-	{
-	    if ( *p == '\\' )
-		p++;
-
-	    if ( *p == ch )
-	    {
-		if (negate)
-		    return false;
-		ok = true;
-	    }
-	}
-    }
-    return ok || negate;
-}
-
-//-----------------------------------------------------------------------------
-
-static bool MatchPatternHelper
-(
-    ccp		pattern,
-    ccp		text,
-    bool	skip_end,
-    int		alt_depth,
-    char	path_sep	// path separator character, standard is '/'
-)
-{
-    ASSERT(pattern);
-    ASSERT(text);
-    noTRACE(" - %d,%d |%s|%s|\n",skip_end,alt_depth,pattern,text);
-
-    char ch;
-    while ( ( ch = *pattern++ ) != 0 )
-    {
-	switch (ch)
-	{
-	   case '*':
-		if ( *pattern == '*' )
-		{
-		    pattern++;
-		    if (*pattern)
-			while (!MatchPatternHelper(pattern,text,skip_end,alt_depth,path_sep))
-			    if (!*text++)
-				return false;
-		}
-		else
-		{
-		    while (!MatchPatternHelper(pattern,text,skip_end,alt_depth,path_sep))
-			if ( *text == path_sep || !*text++ )
-			    return false;
-		}
-		return true;
-
-	    case '#':
-	 	if ( *text < '0' || *text > '9' )
-		    return false;
-		while ( *text >= '0' && *text <= '9' )
-			if (MatchPatternHelper(pattern,++text,skip_end,alt_depth,path_sep))
-			    return true;
-		return false;
-
-	    case ' ':
-		if ( *text < 1 || * text > ' ' )
-		    return false;
-		text++;
-		break;
-
-	    case '?':
-		if ( !*text || *text == path_sep )
-		    return false;
-		text++;
-		break;
-
-	    case '[':
-		{
-		    ccp start;
-		    bool negate;
-		    int multiple;
-		    TRACELINE;
-		    pattern = AnalyseBrackets(pattern,&start,&negate,&multiple);
-		    TRACELINE;
-
-		    if ( multiple < 2 && !MatchBracktes(*text++,start,negate) )
-			return false;
-
-		    if (multiple)
-		    {
-			while (!MatchPatternHelper(pattern,text,skip_end,alt_depth,path_sep))
-			    if (!MatchBracktes(*text++,start,negate))
-				return false;
-			return true;
-		    }
-		}
-		break;
-
-	   case '{':
-		for (;;)
-		{
-		    if (MatchPatternHelper(pattern,text,skip_end,alt_depth+1,path_sep))
-			return true;
-		    // skip until next ',' || '}'
-		    int skip_depth = 1;
-		    while ( skip_depth > 0 )
-		    {
-			ch = *pattern++;
-			switch(ch)
-			{
-			    case 0:
-				return false;
-
-			    case '\\':
-				if (!*pattern)
-				    return false;
-				pattern++;
-				break;
-
-			    case '{':
-				skip_depth++;
-				break;
-
-			    case ',':
-				if ( skip_depth == 1 )
-				    skip_depth--;
-				break;
-
-			    case '}':
-				if (!--skip_depth)
-				    return false;
-				break;
-
-			    case '[': // [[2do]] forgotten marker?
-				pattern = AnalyseBrackets(pattern,0,0,0);
-				break;
-			}
-		    }
-		}
-
-	   case ',':
-		if (alt_depth)
-		{
-		    alt_depth--;
-		    int skip_depth = 1;
-		    while ( skip_depth > 0 )
-		    {
-			ch = *pattern++;
-			switch(ch)
-			{
-			    case 0:
-				return false;
-
-			    case '\\':
-				if (!*pattern)
-				    return false;
-				pattern++;
-				break;
-
-			    case '{':
-				skip_depth++;
-				break;
-
-			    case '}':
-				skip_depth--;
-				break;
-
-			    case '[': // [[2do]] forgotten marker?
-				pattern = AnalyseBrackets(pattern,0,0,0);
-				break;
-			}
-		    }
-		}
-		else if ( *text++ != ch )
-		    return false;
-		break;
-
-	   case '}':
-		if ( !alt_depth && *text++ != ch )
-		    return false;
-		break;
-
-	   case '$':
-		if ( !*pattern && !*text )
-		    return true;
-		if ( *text++ != ch )
-		    return false;
-		break;
-
-	   case '\\':
-		ch = *pattern++;
-		// fall through
-
-	   default:
-		if ( *text++ != ch )
-		    return false;
-		break;
-	}
-    }
-    return skip_end || *text == 0;
-}
-
-//-----------------------------------------------------------------------------
-
-bool MatchPattern
-(
-    ccp		pattern,	// pattern text
-    ccp		text,		// raw text
-    char	path_sep	// path separator character, standard is '/'
-)
-{
-    TRACE("MatchPattern(|%s|%s|%c|)\n",pattern,text,path_sep);
-    if ( !pattern || !*pattern )
-	return true;
-
-    if (!text)
-	text = "";
-
-    const size_t plen = strlen(pattern);
-    ccp last = pattern + plen - 1;
-    char last_ch = *last;
-    int count = 0;
-    while ( last > pattern && *--last == '\\' )
-	count++;
-    if ( count & 1 )
-	last_ch = 0; // no special char!
-	
-    if ( *pattern == path_sep )
-    {
-	pattern++;
-	return MatchPatternHelper(pattern,text++,last_ch!='$',0,path_sep);
-    }
-
-    while (*text)
-	if (MatchPatternHelper(pattern,text++,0,0,path_sep))
-	    return true;
-
-    return false;
-}
-
 //
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////                     END                         ///////////////
