@@ -9,14 +9,14 @@
  *                         \/  \/     |_|    |_|                           *
  *                                                                         *
  *                           Wiimms ISO Tools                              *
- *                         http://wit.wiimm.de/                            *
+ *                         https://wit.wiimm.de/                           *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
  *   This file is part of the WIT project.                                 *
- *   Visit http://wit.wiimm.de/ for project details and sources.           *
+ *   Visit https://wit.wiimm.de/ for project details and sources.          *
  *                                                                         *
- *   Copyright (c) 2009-2015 by Dirk Clemens <wiimm@wiimm.de>              *
+ *   Copyright (c) 2009-2017 by Dirk Clemens <wiimm@wiimm.de>              *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
@@ -37,7 +37,7 @@
 #ifndef WIT_MATCH_PATTERN_H
 #define WIT_MATCH_PATTERN_H 1
 
-#include "types.h"
+#include "dclib/dclib-types.h"
 #include "wiidisc.h"
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -100,16 +100,6 @@ int MatchFilePatternFST
 	struct wd_iterator_t *it	// iterator struct with all infos
 );
 
-///////////////////////////////////////////////////////////////////////////////
-// low level match pattern function
-
-bool MatchPattern
-(
-    ccp		pattern,	// pattern text
-    ccp		text,		// raw text
-    char	path_sep	// path separator character, standard is '/'
-);
-
 ///////////////////////////////////////////////////////////////////////////////
 
 #endif // WIT_MATCH_PATTERN_H
