@@ -9,14 +9,14 @@
  *                         \/  \/     |_|    |_|                           *
  *                                                                         *
  *                           Wiimms ISO Tools                              *
- *                         http://wit.wiimm.de/                            *
+ *                         https://wit.wiimm.de/                           *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
  *   This file is part of the WIT project.                                 *
- *   Visit http://wit.wiimm.de/ for project details and sources.           *
+ *   Visit https://wit.wiimm.de/ for project details and sources.          *
  *                                                                         *
- *   Copyright (c) 2009-2015 by Dirk Clemens <wiimm@wiimm.de>              *
+ *   Copyright (c) 2009-2017 by Dirk Clemens <wiimm@wiimm.de>              *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
@@ -59,7 +59,7 @@ int opt_hook = 0; // <0: disabled, =0: auto, >0: enabled
 
 enumEncoding ScanEncoding ( ccp arg )
 {
-    static const CommandTab_t tab[] =
+    static const KeywordTab_t tab[] =
     {
 	{ 0,			"AUTO",		0,		ENCODE_MASK },
 
@@ -75,7 +75,7 @@ enumEncoding ScanEncoding ( ccp arg )
 	{ 0,0,0,0 }
     };
 
-    const int stat = ScanCommandListMask(arg,tab);
+    const int stat = ScanKeywordListMask(arg,tab);
     if ( stat >= 0 )
 	return stat & ENCODE_MASK;
 
@@ -133,7 +133,7 @@ enumEncoding SetEncoding
 
 enumRegion ScanRegion ( ccp arg )
 {
-    static const CommandTab_t tab[] =
+    static const KeywordTab_t tab[] =
     {
 	{ REGION_JAP,		"JAPAN",	"JAP",		0 },
 	{ REGION_USA,		"USA",		0,		0 },
@@ -146,7 +146,7 @@ enumRegion ScanRegion ( ccp arg )
 	{ 0,0,0,0 }
     };
 
-    const int stat = ScanCommandListMask(arg,tab);
+    const int stat = ScanKeywordListMask(arg,tab);
     if ( stat >= 0 )
 	return stat;
 
@@ -199,12 +199,12 @@ static const RegionInfo_t RegionTable[] =
 
 	/*A*/ { REGION_EUR,  0, "ALL ", "All" },
 	/*B*/ { REGION_EUR,  0, "-?- ", "-?-" },
-	/*C*/ { REGION_EUR,  0, "-?- ", "-?-" },
+	/*C*/ { REGION_EUR,  0, "CHIN", "Chinese" },
 	/*D*/ { REGION_EUR, 1,  "GERM", "German" },
 	/*E*/ { REGION_USA, 1,  "USA ", "NTSC/USA" },
 	/*F*/ { REGION_EUR, 1,  "FREN", "French" },
 	/*G*/ { REGION_EUR,  0, "-?- ", "-?-" },
-	/*H*/ { REGION_EUR,  0, "NL  ", "Netherlands" },	// ??
+	/*H*/ { REGION_EUR,  0, "NL  ", "Netherlands" },
 	/*I*/ { REGION_EUR, 1,  "ITAL", "Italian" },
 	/*J*/ { REGION_JAP, 1,  "JAPA", "Japan" },
 	/*K*/ { REGION_KOR, 1,  "KORE", "Korea" },
@@ -217,12 +217,12 @@ static const RegionInfo_t RegionTable[] =
 	/*R*/ { REGION_EUR, 1,  "RUS ", "Russia" },
 	/*S*/ { REGION_EUR, 1,  "SPAN", "Spanish" },
 	/*T*/ { REGION_KOR, 1,  "KO/E", "Korea (english)" },
-	/*U*/ { REGION_EUR,  0, "AUS ", "Australia" },		// ??
-	/*V*/ { REGION_EUR,  0, "SCAN", "Scandinavian" },	// ??
-	/*W*/ { REGION_EUR,  0, "CHIN", "China" },		// ??
-	/*X*/ { REGION_EUR, 1,  "RF  ", "Region free" },
-	/*Y*/ { REGION_EUR,  0, "-?- ", "-?-" },
-	/*Z*/ { REGION_EUR,  0, "-?- ", "-?-" },
+	/*U*/ { REGION_EUR,  0, "AUS ", "Australia" },
+	/*V*/ { REGION_EUR,  0, "SCAN", "Scandinavian" },
+	/*W*/ { REGION_EUR,  0, "TAIW", "Taiwan" },
+	/*X*/ { REGION_EUR, 1,  "EURO", "Almost Europe" },
+	/*Y*/ { REGION_EUR,  0, "EURO", "Almost Europe" },
+	/*Z*/ { REGION_EUR,  0, "ANY ", "PAL or US" },
 
 	/*?*/ { REGION_EUR,  0, "-?- ", "-?-" } // illegal region_code
 };
@@ -244,16 +244,19 @@ const RegionInfo_t * GetRegionInfo ( char region_code )
 
 wd_ckey_index_t ScanCommonKey ( ccp arg )
 {
-    static const CommandTab_t tab[] =
+    static const KeywordTab_t tab[] =
     {
 	{ WD_CKEY_STANDARD,	"STANDARD",	0,		0 },
 	{ WD_CKEY_KOREA,	"KOREAN",	0,		0 },
+ #ifdef SUPPORT_CKEY_DEVELOP
+	{ WD_CKEY_DEVELOPER,	"DEVELOPER",	0,		0 },
+ #endif
 	{ WD_CKEY__N,		"AUTO",		0,		0 },
 
 	{ 0,0,0,0 }
     };
 
-    const int stat = ScanCommandListMask(arg,tab);
+    const int stat = ScanKeywordListMask(arg,tab);
     if ( stat >= 0 )
 	return stat;
 
@@ -276,6 +279,9 @@ int ScanOptCommonKey ( ccp arg )
     const wd_ckey_index_t new_common_key = ScanCommonKey(arg);
     if ( new_common_key == -1 )
 	return 1;
+ #ifdef TEST
+    printf("COMMON-KEY: %d -> %d\n",opt_common_key,new_common_key);
+ #endif
     opt_common_key = new_common_key;
     return 0;
 }
@@ -497,7 +503,7 @@ int patch_main ( wd_disc_t * disc )
 
 wd_modify_t ScanModify ( ccp arg )
 {
-    static const CommandTab_t tab[] =
+    static const KeywordTab_t tab[] =
     {
 	{ WD_MODIFY__NONE,	"NONE",		"-",	WD_MODIFY__ALL },
 	{ WD_MODIFY__ALL,	"ALL",		0,	WD_MODIFY__ALL },
@@ -513,7 +519,7 @@ wd_modify_t ScanModify ( ccp arg )
 	{ 0,0,0,0 }
     };
 
-    const int stat = ScanCommandList(arg,tab,0,true,0,0);
+    const int stat = ScanKeywordList(arg,tab,0,true,0,0,0,0);
     if ( stat >= 0 )
 	return ( stat & WD_MODIFY__ALL ? stat & WD_MODIFY__ALL : stat ) | WD_MODIFY__ALWAYS;
 
@@ -864,7 +870,7 @@ wd_trim_mode_t ScanTrim
     ccp err_text_extend		// error message extention
 )
 {
-    static const CommandTab_t tab[] =
+    static const KeywordTab_t tab[] =
     {
 	{ WD_TRIM_DEFAULT,	"DEFAULT",	0,	WD_TRIM_M_ALL },
 
@@ -882,7 +888,7 @@ wd_trim_mode_t ScanTrim
 	{ 0,0,0,0 }
     };
 
-    const int stat = ScanCommandList(arg,tab,0,true,0,0);
+    const int stat = ScanKeywordList(arg,tab,0,true,0,0,0,0);
     if ( stat >= 0 )
 	return stat;
 
