@@ -9,14 +9,14 @@
  *                         \/  \/     |_|    |_|                           *
  *                                                                         *
  *                           Wiimms ISO Tools                              *
- *                         http://wit.wiimm.de/                            *
+ *                         https://wit.wiimm.de/                           *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
  *   This file is part of the WIT project.                                 *
- *   Visit http://wit.wiimm.de/ for project details and sources.           *
+ *   Visit https://wit.wiimm.de/ for project details and sources.          *
  *                                                                         *
- *   Copyright (c) 2009-2015 by Dirk Clemens <wiimm@wiimm.de>              *
+ *   Copyright (c) 2009-2017 by Dirk Clemens <wiimm@wiimm.de>              *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
@@ -39,7 +39,7 @@
 
 #include <stdio.h>
 
-#include "types.h"
+#include "dclib/dclib-types.h"
 #include "lib-sf.h"
 #include "iso-interface.h"
 
@@ -275,7 +275,7 @@ typedef struct AWData_t
 
 //-----------------------------------------------------------------------------
 
-int AnalyzeWBFS      ( AWData_t * ad, File_t * f );
+int AnalyzeWBFS      ( AWData_t * ad, WFile_t * f );
 int PrintAnalyzeWBFS
 (
     FILE		* out,		// valid output stream
